import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:flutter_flicker/configuration/configuration.dart';

class FlickerTextInput extends StatelessWidget {
  FlickerTextInput({
    Key? key,
    this.initialValue,
    this.onChanged,
    this.controller,
    this.labelText,
    this.validator,
    this.obscureText = false,
    this.numberOfLines = 1,
    this.padding = const EdgeInsets.only(
      top: 8.0,
      right: 8.0,
    ),
    this.width = 250,
    this.readOnly = false,
    this.suffix,
    this.prefix,
  }) : super(key: key);

  final String? initialValue;
  final String? labelText;
  final ValueChanged<String>? onChanged;
  final FormFieldValidator<String>? validator;
  final bool obscureText;
  final int numberOfLines;
  final EdgeInsetsGeometry padding;
  final double width;
  final bool readOnly;
  final Widget? suffix;
  final Widget? prefix;
  final TextEditingController? controller;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      margin: padding,
      alignment: Alignment.center,
      child: TextFormField(
        controller: controller,
        initialValue: initialValue,
        obscureText: obscureText,
        readOnly: readOnly,
        obscuringCharacter: '*',
        onChanged: onChanged,
        cursorColor: FlickerConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: FlickerConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          suffix: suffix,
          prefix: prefix,
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText!.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: FlickerConfiguration.colors.hintText,
          ),
          hintText: labelText != null
              ? readOnly
                  ? ' '
                  : labelText!.toUpperCase()
              : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: readOnly
                ? Colors.grey.shade700
                : FlickerConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        validator: validator,
        maxLines: numberOfLines,
      ),
    );
  }
}
